@@ -2,15 +2,10 @@ print.starship <- function(x,digits = max(3, getOption("digits") - 3), ...)
 {
 # I should include the call
 # Add names to the vector in starship
-if(is.character(x$method.name)) {
-  cat(paste(x$param,"parameterisation,",x$method.name,"estimate\n"))
-} else {
-cat(paste(x$param,"parameterisation\n"))}
+cat(paste(x$param,"parameterisation\n"))
 print.default(format(x$lambda,digits=digits), print.gap = 2,quote=FALSE)
 }
 
-### Something wrong here for fkml parameterisation
-
 summary.starship <- function(object,...)
 {
 cat("\nAdaptive Grid estimates:\n")
@@ -18,11 +13,11 @@ fake.lambda <- object$grid.results$lambda
 names(fake.lambda) <- paste("lambda",1:length(fake.lambda),sep="")
 fake.starship.object <- list(param=object$param,lambda=fake.lambda)
 print.starship(fake.starship.object)
-cat(paste("objective function at grid minimum:",
+cat(paste("internal g-o-f measure at grid minimum:",
 format(object$grid.results$response),"\n"))
 cat("\nOptim (final) estimates (starting from grid estimates):\n")
 print.starship(object)
-cat(paste("objective function at optim minimum:",
+cat(paste("internal g-o-f measure at optim minimum:",
 format(object$optim.results$value),"\n"))
 cat("optim.details:\nCounts: ")
 print(object$optim.results$counts)
@@ -30,8 +25,6 @@ cat("Convergence: ")
 print(object$optim.results$convergence)
 cat("Message: ")
 print(object$optim.results$message)
-cat("Method: ")
-print(object$optim.results$optim.method)
 }
 
 plot.starship <- function(x,data=NULL,ask=FALSE,one.page=TRUE,breaks="Sturges",histogram.title=NULL,...)
@@ -47,7 +40,7 @@ if (is.null(x$data)){
 if (ask) {par(ask=TRUE)}
 if (one.page) {par(mfrow=c(2,1))}
 qqgl(y=data,lambda.pars1=x$lambda,param=x$param,xlab="Fitted Theoretical Quantiles")
-hist(x=data,prob=TRUE,xlab="Data",breaks=breaks,main=histogram.title,...)
+hist(data,prob=TRUE,xlab="Data",breaks=breaks,main=histogram.title,...)
 plotgld(lambda1=x$lambda,param=x$param,new.plot=FALSE,...)
 par(opar) # Return to previous par
 }
